sqlobject.inheritance.tests.test\_destroy\_cascade module
=========================================================

.. automodule:: sqlobject.inheritance.tests.test_destroy_cascade
    :members:
    :undoc-members:
    :show-inheritance:
